Saltware / Mbed 2 deprecated Water Play

Dependencies:   mbed DRV88255 TextLCD Ping mbed-rtos

Revision:
57:8dc3192ff150
Parent:
53:4e3ee54157ad
--- a/Controller.h	Sun Jun 19 20:55:16 2016 +0000
+++ b/Controller.h	Sun Jun 19 22:21:08 2016 +0000
@@ -6,7 +6,7 @@
 #include "rtos.h"
 
 /** The base class for everything which interfaces with sensors or actuators.
  * Extending classes must implement \a std::string \a get_name() and \a void \a update()
  */
 class Controller {
     public:
@@ -22,13 +22,13 @@
          * Returns the name of this Controller. Must be implemented by extending classes.
          * @return The name of this Controller.
         */        
-        virtual std::string get_name() = 0;
+        virtual std::string getName() = 0;
         
         /**
          * Returns whether or not this Controller is being threaded.
          * @return \a true if this Controller is being threaded, \a false otherwise.
         */   
-        bool is_threaded();
+        bool isThreaded();
 
         /**
          * If this Controller is not threaded, \a update() is called. Otherwise, the first time a thread is spawned which repeatedly calls \a update().
@@ -40,19 +40,19 @@
          * Returns the interval between each iteration if threaded.
          * @return \a interval_ms as specified in the constructor.
         */                 
-        int get_interval_ms();
+        int getIntervalMs();
 
         /**
          * Sets the underlying RTOS thread priority.
          * @see cmis_os.h
         */           
-        void set_priority(osPriority priority);
+        void setPriority(osPriority priority);
 
         /**
          * Returns the thread priority.
          * @return the thread priority.
         */           
-        osPriority get_priority();
+        osPriority getPriority();
         
     protected:
         /**
@@ -94,7 +94,7 @@
         /**
          * This function is called when the thread is created, it repeatedly calls \a run() and waits for \a interval_ms milliseconds.
         */        
-        static void thread_stub(void const *args);
+        static void threadStub(void const *args);
 };
 
 #endif
@@ -6,7 +6,7 @@
 
 /** The base class for everything which interfaces with sensors or actuators.
- * Extending classes must implement \a std::string \a get_name() and \a void \a update()
+ * Extending classes must implement \a std::string \a getName() and \a void \a update()
  */
 class Controller {
\ No newline at end of file